# **XPL**
Xidware Python Library

## **Specification**

### **Development Environment**
- **Operating System**: Windows
- **Python Version**: Python 3.10.11
- **Editor**: Visual Studio Code (VSCode)

### **Supported Environments**
- **Operating Systems**: Windows, Linux, macOS
- **Python Version**: Python 3.9.7+
- **Editor**: Any editor (VSCode, PyCharm, etc.)

## **Manual**

### **Installation**
To install `xpl`, use the following pip command:
```cmd
pip install xid-xpl
```

### **Tutorial**
```python
from xpl import BaseClass

class MyClass(BaseClass):
    pass
```